# Metadata for the widget EGG. Should leave it for the (unimplemented) widget
# tracker to track it

__PROJECT__ = 'tw.mochikit'
__DESCRIPTION__ = 'MochiKit 1.4 (dev) widget for ToscaWidgets'
__URL__ = 'http://toscawidgets.org'
__VERSION__ = '0.8'
__AUTHOR__ = 'Alberto Valverde Gonzalez'
__EMAIL__ = "alberto@toscat.net"
__COPYRIGHT__ = "Copyright 2006 Alberto Valverde Gonzalez"
__LICENSE__ = 'MIT'
